@@ -164,6 +164,29 @@ function sent_conf_options_save() {
 //
 function sent_conf_message_sent_do() {
 
+
+   // if saving as a draft, this plugin should be ignored
+   //
+   global $draft; if ($draft) return;
+
+
+   // first, check if the restrict_senders plugin 
+   // is installed and if so, it needs to run first
+   //
+   global $plugins;
+
+   if (in_array('restrict_senders', $plugins))
+   {
+      global $restrict_senders_finished, $sent_confirmation_was_delayed;
+      if (!$restrict_senders_finished)
+      {
+         $sent_confirmation_was_delayed = 1;
+         return;
+      }
+   }
+
+
+
    global $sent_confirmation_debug, $sent_conf_message_sent_status,
           $sent_conf_include_recip_addr, $send_to, $send_to_cc, $send_to_bcc,
           $sent_conf_show_only_first_recip_addr, 
@@ -182,6 +205,9 @@ function sent_conf_message_sent_do() {
    else
       include_once ('../plugins/sent_confirmation/config.php');
 
+
+   // get all our config set up
+   //
    if ($sent_conf_allow_user_override)
    {
       $sent_conf_message_style = getPref($data_dir, $username, 'sent_conf_style', $sent_conf_message_style);
@@ -193,6 +219,9 @@ function sent_conf_message_sent_do() {
       $sent_conf_enable_orig_msg_options = getPref($data_dir, $username, 'sent_conf_enable_orig_msg_options', $sent_conf_enable_orig_msg_options);
    }
 
+
+   // build information to be passed to display function below
+   //
    $sent_conf_message_sent_status = 'sent';
 
    if ($sent_conf_include_recip_addr)
@@ -240,7 +269,8 @@ function sent_conf_message_sent_do() {
    $sent_conf_orig_subject = '';
    $sent_conf_orig_sender = '';
    $sent_conf_mbox_list = '';
-   if ($sent_conf_enable_orig_msg_options && strpos($action, 'reply') !== FALSE)
+   if ($sent_conf_message_style > 2 && $sent_conf_enable_orig_msg_options 
+   && (strpos($action, 'reply') !== FALSE || strpos($action, 'forward') !== FALSE))
    {
       $sent_conf_orig_reply_msg = $mailbox . '|' . $passed_id . '|' . $sort;
 
@@ -261,8 +291,6 @@ function sent_conf_message_sent_do() {
       $sent_conf_mbox_list = sqimap_mailbox_option_list($imapConnection, 
                                                         array(strtolower($lastTargetMailbox)));
 
-// TODO: Thjis just committed functionality to have the correct startMessage when sending
-//       replies... get that here...
    }
 
 
@@ -293,19 +321,44 @@ function sent_conf_message_sent_do() {
 //
 function sent_conf_check_is_sent_do() {
 
+
+   // get global variable for versions of PHP < 4.1
+   //
+   if (!compatibility_check_php_version(4,1)) {
+      global $HTTP_SERVER_VARS;
+      $_SERVER = $HTTP_SERVER_VARS;
+   }
+
+
+   // this is called in the generic header, so we 
+   // only want to do this when we are on the right_main
+   // page (unless "compose in new window" is on, in
+   // which case we want to do it in the compose page,
+   // or we are on the compose page and we have "mail_sent",
+   // meaning that a draft was just resumed and sent)
+   //
+   global $compose_new_win, $mail_sent;
+   if (($compose_new_win && !stristr($_SERVER['SCRIPT_NAME'], 'compose.php'))
+   || (!$compose_new_win && !stristr($_SERVER['SCRIPT_NAME'], 'right_main.php')
+      && !($mail_sent && stristr($_SERVER['SCRIPT_NAME'], 'compose.php'))))
+      return;
+   
+
+
    global $sent_conf_message_sent_status, $color, $sent_confirmation_debug, 
           $sent_conf_message_style, $sent_conf_include_recip_addr, 
           $sent_conf_allow_user_override, $data_dir, $username,
           $sent_conf_show_headers, $sent_conf_orig_reply_msg,
           $sent_conf_orig_subject, $sent_conf_orig_sender, 
           $sent_conf_enable_orig_msg_options, $compose_new_win,
-          $sent_conf_mbox_list;
+          $sent_conf_mbox_list, $blockedAddresses;
 
    compatibility_sqextractGlobalVar('sent_conf_message_sent_status');
    compatibility_sqextractGlobalVar('sent_conf_orig_reply_msg');
    compatibility_sqextractGlobalVar('sent_conf_orig_subject');
    compatibility_sqextractGlobalVar('sent_conf_orig_sender');
    compatibility_sqextractGlobalVar('sent_conf_mbox_list');
+   compatibility_sqextractGlobalVar('blockedAddresses');
 
    if (compatibility_check_sm_version(1, 3))
       include_once (SM_PATH . 'plugins/sent_confirmation/config.php');
@@ -348,28 +401,103 @@ function sent_conf_check_is_sent_do() {
           && $sent_conf_message_style != 'off')
    {
 
+
+      // a little trickery to get the page header
+      // printed out... the problem is that this
+      // function is called in a hook that is part
+      // of displayPageHeader(), so we need to avoid
+      // an endless recursion loop here
+      //
+      global $color, $sent_conf_count;
+      if (!$sent_conf_count)
+      {
+         $sent_conf_count = 1;
+         displayPageHeader($color, 'None');
+      }
+      else
+      {
+         return;
+      }
+
+
       echo '<table width="100%" bgcolor="' . $color[0] 
          . '" cellpadding="0" cellspaceing="0"><tr><td>';
 
       if ($sent_conf_message_style == 1)
       {
          if ($sent_conf_include_recip_addr)
+         {
             echo '<strong>' . _("Message Sent To: ") 
-               . $sent_conf_message_sent_status . '</strong>';
+               . $sent_conf_message_sent_status;
+ 
+
+            // if any disallowed addresses from the
+            // restrict senders plugin, display them
+            //
+            if ($blockedAddresses)
+            {
+               echo '<br><font color="' . $color[1] . '">BLOCKED ADDRESSES: ';
+               $first = 1;
+               foreach ($blockedAddresses as $badAddr)
+               {
+                  if (!$first) echo ', ';
+                  $first = 0;
+                  echo $badAddr;
+               }
+               echo '</font>';
+            }
+            echo '</strong>';
+         }
          else
             echo '<strong>' . _("Message Sent") . '</strong>';
       }
       else if ($sent_conf_message_style == 2)
       {
          if ($sent_conf_include_recip_addr)
+         {
             echo '<strong><center>' . _("Your message has been sent to ") 
-               . $sent_conf_message_sent_status . '</center></strong>';
+               . $sent_conf_message_sent_status;
+
+            // if any disallowed addresses from the
+            // restrict senders plugin, display them
+            //
+            if ($blockedAddresses)
+            {
+               echo '<br><font color="' . $color[1] . '">BLOCKED ADDRESSES: ';
+               $first = 1;
+               foreach ($blockedAddresses as $badAddr)
+               {
+                  if (!$first) echo ', ';
+                  $first = 0;
+                  echo $badAddr;
+               }
+               echo '</font>';
+            }
+            echo '</center></strong>';
+         }
          else
             echo '<strong><center>' . _("Your message has been sent") . '</center></strong>';
       }
       else if ($sent_conf_message_style == 3)
       {
 
+         // if the quicksave plugin is installed and active, we 
+         // need to tell it here that the message was sent successfully
+         // (in case the user doesn't return to the message list, 
+         // where quicksave usually does this for itself)
+         //
+         global $plugins;
+         if (in_array('quicksave', $plugins))
+         {
+            if (compatibility_check_sm_version(1, 3))
+               include_once (SM_PATH . 'plugins/quicksave/functions.php');
+            else
+               include_once ('../plugins/quicksave/functions.php');
+
+            quicksave_turn_off();
+         }
+
+
          // code stolen from /src/read_body.php as 
          // well as Wolf Bergenheim's Todo plugin
          //
@@ -379,7 +507,7 @@ function sent_conf_check_is_sent_do() {
 
 
          echo '<TABLE CELLSPACING="0" WIDTH="100%" BORDER="0" ALIGN="CENTER" CELLPADDING="0">' 
-            . '<TR><TD BGCOLOR="' . $color[9] . '" WIDTH="100%">' 
+            . '<TR><TD BGCOLOR="' . $color[9] . '" WIDTH="100%">'
             . '<TABLE WIDTH="100%" CELLSPACING="0" BORDER="0" CELLPADDING="3">' 
             . '<TR>' 
             . '<TD ALIGN="LEFT" WIDTH="100%">' 
@@ -497,13 +625,6 @@ function sent_conf_check_is_sent_do() {
                . '<input type="hidden" name="location" value="'
                . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox"
                . '">'
-
-// TODO: Thjis just committed a fix to DEVEL that allows the start message to be correct
-//       when having sent a reply... we should get and use that here...
-////               . '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">'
-// and then delete this line:
-. '<input type="hidden" name="startMessage" value="1">'
-
                . "\n"
                . '<table><tr><td colspan="2" align="center"><small><strong>' . _("Original Message") 
                . '<strong></small><hr></td></tr><tr><td align="right"><small><strong>' . _("From") 
@@ -513,9 +634,9 @@ function sent_conf_check_is_sent_do() {
 ////               . '<tr><td colspan="2" align="center"><hr></td></tr>'
                . '<tr><td colspan="2" align="center"><small><br><a href="../src/delete_message.php?mailbox='
                . $mailbox . '&message=' . $passed_id . '&sort=' . $sort 
-               . '&startMessage=1">Delete</a> | <a href="../src/read_body.php?mailbox='
+               . '&startMessage=' . $startMessage . '">Delete</a> | <a href="../src/read_body.php?mailbox='
                . $mailbox . '&passed_id=' . $passed_id 
-               . '&startMessage=1">Return To Message</a></small>'
+               . '&startMessage=' . $startMessage . '">Return To Message</a></small>'
                . '</td></tr><tr><td align="center" colspan="2"><small>' 
                . _("Move to:") . ' <select name="targetMailbox">' . $sent_conf_mbox_list
                . '</SELECT>&nbsp;'
@@ -526,6 +647,7 @@ function sent_conf_check_is_sent_do() {
 
 // read links as constructed in mailbox_display.php
 // but stuff like startMessage and searchstr don't
+//////// note - startMessage has been fixed
 // appear to be available after the send button is 
 // pressed
 //
@@ -544,6 +666,19 @@ function sent_conf_check_is_sent_do() {
 
          }
 
+
+         // if any disallowed addresses from the
+         // restrict senders plugin, display them
+         //
+         if ($blockedAddresses)
+         {
+            echo '</td></tr><tr><td align="center"><strong><font color="' . $color[1] . '">' . _("BLOCKED ADDRESSES") . ':</font></strong></td></tr>'."\n"
+               . '<tr><td align="center"><table border=0 cellspacing=0 cellpadding=0>'."\n";
+            foreach ($blockedAddresses as $badAddr)
+               echo '<tr><td><font color="' . $color[1] . '">' . $badAddr . '</font></td></tr>';
+            echo '</table>';
+         }
+
          echo '</td></tr></table>'
             . '</td></tr></table>';
 
@@ -568,7 +703,6 @@ function sent_conf_check_is_sent_do() {
          echo '</td></tr></table>'
             . '</body></html>';
 
-//global $username; if ($username == 'paul@angrynerds.com') exit;
          $sent_conf_message_sent_status = 'not_sent';
          compatibility_sqsession_register($sent_conf_message_sent_status, 
                                           'sent_conf_message_sent_status');
@@ -578,6 +712,24 @@ function sent_conf_check_is_sent_do() {
       else if ($sent_conf_message_style == 4)
       {
 
+
+         // if the quicksave plugin is installed and active, we
+         // need to tell it here that the message was sent successfully
+         // (in case the user doesn't return to the message list,
+         // where quicksave usually does this for itself)
+         //
+         global $plugins;
+         if (in_array('quicksave', $plugins))
+         {
+            if (compatibility_check_sm_version(1, 3))
+               include_once (SM_PATH . 'plugins/quicksave/functions.php');
+            else
+               include_once ('../plugins/quicksave/functions.php');
+
+            quicksave_turn_off();
+         }
+
+
          // code stolen from /src/read_body.php as 
          // well as Wolf Bergenheim's Todo plugin
          //
@@ -698,13 +850,6 @@ function sent_conf_check_is_sent_do() {
                . '<input type="hidden" name="location" value="'
                . "right_main.php?sort=$sort&amp;startMessage=$startMessage&amp;mailbox=$urlMailbox"
                . '">'
-
-// TODO: Thjis just committed a fix to DEVEL that allows the start message to be correct
-//       when having sent a reply... we should get and use that here...
-////               . '<input type="hidden" name="startMessage" value="'.htmlspecialchars($start_msg).'">'
-// and then delete this line:
-. '<input type="hidden" name="startMessage" value="1">'
-
                . "\n"
                . '<table><tr><td colspan="2" align="center"><small><strong>' . _("Original Message") 
                . '<strong></small><hr></td></tr><tr><td align="right"><small><strong>' . _("From") 
@@ -714,9 +859,9 @@ function sent_conf_check_is_sent_do() {
 ////               . '<tr><td colspan="2" align="center"><hr></td></tr>'
                . '<tr><td colspan="2" align="center"><small><br><a href="../src/delete_message.php?mailbox='
                . $mailbox . '&message=' . $passed_id . '&sort=' . $sort 
-               . '&startMessage=1">Delete</a> | <a href="../src/read_body.php?mailbox='
+               . '&startMessage=' . $startMessage . '">Delete</a> | <a href="../src/read_body.php?mailbox='
                . $mailbox . '&passed_id=' . $passed_id 
-               . '&startMessage=1">Return To Message</a></small>'
+               . '&startMessage=' . $startMessage . '">Return To Message</a></small>'
                . '</td></tr><tr><td align="center" colspan="2"><small>' 
                . _("Move to:") . ' <select name="targetMailbox">' . $sent_conf_mbox_list
                . '</SELECT>&nbsp;'
@@ -727,6 +872,7 @@ function sent_conf_check_is_sent_do() {
 
 // read links as constructed in mailbox_display.php
 // but stuff like startMessage and searchstr don't
+//////// note - startMessage has been fixed
 // appear to be available after the send button is 
 // pressed
 //
@@ -746,8 +892,21 @@ function sent_conf_check_is_sent_do() {
          }
 
 
+         // if any disallowed addresses from the
+         // restrict senders plugin, display them
+         //
+         if ($blockedAddresses)
+         {
+            echo '</td></tr><tr><td align="center"><strong><font color="' . $color[1] . '">' . _("BLOCKED ADDRESSES") . ':</font></strong></td></tr>'."\n"
+               . '<tr><td align="center"><table border=0 cellspacing=0 cellpadding=0>'."\n";
+            foreach ($blockedAddresses as $badAddr)
+               echo '<tr><td><font color="' . $color[1] . '">' . $badAddr . '</font></td></tr>';
+            echo '</table>';
+         }
+
          echo '</td></tr></table>'
             . '</td></tr></table>';
+
          echo '<TABLE WIDTH="100%" CELLSPACING="0" BORDER="0" CELLPADDING="3">' 
             . '<TR>' 
             . '<TD ALIGN="RIGHT" WIDTH="100%"><br>' 
