@@ -6,14 +6,13 @@ function squirrelmail_plugin_init_sent_confirmation()
 
 	global $squirrelmail_plugin_hooks;
 
-        $squirrelmail_plugin_hooks ['compose_send']['sent_confirmation']            = 'sent_conf_message_sent';
-        $squirrelmail_plugin_hooks ['right_main_after_header']['sent_confirmation'] = 'sent_conf_check_is_sent';
-        $squirrelmail_plugin_hooks ['compose_top']['sent_confirmation'] = 'sent_conf_check_is_sent';
-        $squirrelmail_plugin_hooks['compose_bottom']['sent_confirmation']           = 'sent_conf_compose_bottom';
+        $squirrelmail_plugin_hooks['compose_send']['sent_confirmation']            = 'sent_conf_message_sent';
+        $squirrelmail_plugin_hooks['generic_header']['sent_confirmation']          = 'sent_conf_check_is_sent';
+        $squirrelmail_plugin_hooks['compose_bottom']['sent_confirmation']          = 'sent_conf_compose_bottom';
 
 
-        $squirrelmail_plugin_hooks['options_display_inside']['sent_confirmation']   = 'sent_conf_show_options';
-        $squirrelmail_plugin_hooks['options_display_save']['sent_confirmation']     = 'sent_conf_save_options';
+        $squirrelmail_plugin_hooks['options_display_inside']['sent_confirmation']  = 'sent_conf_show_options';
+        $squirrelmail_plugin_hooks['options_display_save']['sent_confirmation']    = 'sent_conf_save_options';
 
 
 }
@@ -24,7 +23,7 @@ function squirrelmail_plugin_init_sent_confirmation()
 //
 function sent_confirmation_version() {
 
-   return '1.1';
+   return '1.2';
 
 }
 
